summaryrefslogtreecommitdiff
path: root/osinfo/osinfo_media.h
diff options
context:
space:
mode:
authorChristophe Fergeau <cfergeau@redhat.com>2011-12-01 10:20:02 +0100
committerChristophe Fergeau <cfergeau@redhat.com>2011-12-02 10:54:35 +0100
commit8f927555524d6f93328117dce338e056c75061e1 (patch)
treefd81193fb22ead25c23114fa06c093e5798a306f /osinfo/osinfo_media.h
parent7a3dd94626d6608b83bff35ff33f4aa5447eeda4 (diff)
downloadlibosinfo-8f927555524d6f93328117dce338e056c75061e1.tar.gz
Fix OSINFO_MEDIA_ERROR_INSUFFIENT_METADATA typo
This is an API change, but I don't think many application are checking error code values of libosinfo errors so I'd say we can do it a this point. A #define for the old symbolic name can be added if we don't want to break the API.
Diffstat (limited to 'osinfo/osinfo_media.h')
-rw-r--r--osinfo/osinfo_media.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/osinfo/osinfo_media.h b/osinfo/osinfo_media.h
index d5208a1..b6a0ee1 100644
--- a/osinfo/osinfo_media.h
+++ b/osinfo/osinfo_media.h
@@ -38,7 +38,7 @@ osinfo_media_error_quark (void) G_GNUC_CONST;
/**
* OsinfoMediaError:
* @OSINFO_MEDIA_ERROR_NO_DESCRIPTORS: No descriptors.
* @OSINFO_MEDIA_ERROR_INSUFFIENT_METADATA: Not enough metadata.
* @OSINFO_MEDIA_ERROR_NOT_BOOTABLE: Install media not bootable.
* @OSINFO_MEDIA_ERROR_NO_PVD: No Primary volume descriptor.
* @OSINFO_MEDIA_ERROR_NO_SVD: No supplementary volume descriptor.
@@ -50,7 +50,7 @@ typedef enum {
OSINFO_MEDIA_ERROR_NO_DESCRIPTORS,
OSINFO_MEDIA_ERROR_NO_PVD,
OSINFO_MEDIA_ERROR_NO_SVD,
- OSINFO_MEDIA_ERROR_INSUFFIENT_METADATA,
+ OSINFO_MEDIA_ERROR_INSUFFICIENT_METADATA,
OSINFO_MEDIA_ERROR_NOT_BOOTABLE
} OsinfoMediaError;
@@ -38,7 +38,7 @@ osinfo_media_error_quark (void) G_GNUC_CONST;
* OsinfoMediaError:
* @OSINFO_MEDIA_ERROR_NO_DESCRIPTORS: No descriptors.
- * @OSINFO_MEDIA_ERROR_INSUFFIENT_METADATA: Not enough metadata.
+ * @OSINFO_MEDIA_ERROR_INSUFFICIENT_METADATA: Not enough metadata.
* @OSINFO_MEDIA_ERROR_NOT_BOOTABLE: Install media not bootable.
* @OSINFO_MEDIA_ERROR_NO_PVD: No Primary volume descriptor.